<?php

namespace Drupal\overseer\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class OverseerSettingsForm.
 */
class OverseerSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'overseer.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'overseer_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('overseer.settings');

    $form['updates_route'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Updates'),
    ];

    $form['updates_route']['access_token'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Access token'),
      '#description' => $this->t('The token that is needed to access the available updates API endpoint.'),
      '#default_value' => $config->get('access_token'),
    ];

    $form['updates_route']['ip_restriction_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable IP restriction'),
      '#default_value' => $config->get('ip_restriction_enabled'),
    ];

    $client_ip = \Drupal::request()->getClientIp();

    $form['updates_route']['allowed_ip_addresses'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Allowed IP addresses'),
      '#description' => $this->t('Enter one IP address per line') . '<br />' . $this->t('Your current IP address is @ip_address', ['@ip_address' => $client_ip]),
      '#default_value' => $config->get('allowed_ip_addresses'),
      '#states' => [
        'visible' => [
          '[name="ip_restriction_enabled"]' => ['checked' => TRUE],
        ],
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('overseer.settings')
      ->set('access_token', $form_state->getValue('access_token'))
      ->set('ip_restriction_enabled', $form_state->getValue('ip_restriction_enabled'))
      ->set('allowed_ip_addresses', $form_state->getValue('allowed_ip_addresses'))
      ->save();
  }

}
